==> v1.0.3.zip: portfolio/web/src/components/Social/Social/Social.tsx <==
import type {
  DeleteSocialMutation,
  DeleteSocialMutationVariables,
  FindSocialById,
} from 'types/graphql'

import { Link, routes, navigate } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import { getLogoComponent } from 'src/lib/handle'

const DELETE_SOCIAL_MUTATION: TypedDocumentNode<
  DeleteSocialMutation,
  DeleteSocialMutationVariables
> = gql`
  mutation DeleteSocialMutation($id: Int!) {
    deleteSocial(id: $id) {
      id
    }
  }
`

interface Props {
  social: NonNullable<FindSocialById['social']>
}

const Social = ({ social }: Props) => {
  const [deleteSocial] = useMutation(DELETE_SOCIAL_MUTATION, {
    onCompleted: () => {
      toast.success('Social deleted')
      navigate(routes.socials())
    },
    onError: (error) => toast.error(error.message),
  })

  const onDeleteClick = (
    name: string,
    id: DeleteSocialMutationVariables['id']
  ) => {
    if (confirm(`Are you sure you want to delete ${name}?`))
      deleteSocial({ variables: { id } })
  }

  return (
    <div className="flex w-full justify-center">
      <div className="w-80">
        <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
          <table className="table">
            <thead className="bg-base-200 font-syne">
              <th className="w-0">
                Social {social.id}: {social.name}
              </th>
              <th>&nbsp;</th>
            </thead>
            <tbody>
              <tr>
                <th>ID</th>
                <td>{social.id}</td>
              </tr>
              <tr>
                <th>Type</th>
                <td>{getLogoComponent(social.type)}</td>
              </tr>
              <tr>
                <th>Name</th>
                <td>{social.name}</td>
              </tr>
              <tr>
                <th>Username</th>
                <td>{social.username}</td>
              </tr>
            </tbody>
          </table>
        </div>
        <nav className="my-2 flex justify-center space-x-2">
          <Link
            to={routes.editSocial({ id: social.id })}
            title={'Edit social ' + social.id}
            className="btn btn-primary btn-sm uppercase"
          >
            Edit
          </Link>
          <button
            type="button"
            title={'Delete social ' + social.id}
            className="btn btn-error btn-sm uppercase"
            onClick={() => onDeleteClick(social.name, social.id)}
          >
            Delete
          </button>
        </nav>
      </div>
    </div>
  )
}

export default Social

==> v1.1.6-1.zip: portfolio/web/src/components/Social/Social/Social.tsx <==
import type {
  DeleteSocialMutation,
  DeleteSocialMutationVariables,
  FindSocialById,
} from 'types/graphql'

import { Link, routes, navigate } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import { getLogoComponent } from 'src/lib/handle'

const DELETE_SOCIAL_MUTATION: TypedDocumentNode<
  DeleteSocialMutation,
  DeleteSocialMutationVariables
> = gql`
  mutation DeleteSocialMutation($id: Int!) {
    deleteSocial(id: $id) {
      id
    }
  }
`

interface Props {
  social: NonNullable<FindSocialById['social']>
}

const Social = ({ social }: Props) => {
  const [deleteSocial] = useMutation(DELETE_SOCIAL_MUTATION, {
    onCompleted: () => {
      toast.success('Social deleted')
      navigate(routes.socials())
    },
    onError: (error) => toast.error(error.message),
  })

  const onDeleteClick = (
    name: string,
    id: DeleteSocialMutationVariables['id']
  ) => {
    if (confirm(`Are you sure you want to delete ${name}?`))
      deleteSocial({ variables: { id } })
  }

  return (
    <div className="flex mx-auto max-w-80 sm:max-w-sm md:max-w-md lg:max-w-lg xl:max-w-xl 2xl:max-w-2xl justify-center">
      <div className="w-full">
        <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
          <table className="table">
            <thead className="bg-base-200 font-syne">
              <tr>
                <th colSpan={2}>
                  Social {social.id}: {social.name}
                </th>
              </tr>
            </thead>
            <tbody>
              <tr>
                <th className="text-right">ID</th>
                <td>{social.id}</td>
              </tr>
              <tr>
                <th className="text-right">Type</th>
                <td>{getLogoComponent(social.type)}</td>
              </tr>
              <tr>
                <th className="text-right">Name</th>
                <td>{social.name}</td>
              </tr>
              <tr>
                <th className="text-right">Username</th>
                <td>{social.username}</td>
              </tr>
            </tbody>
          </table>
        </div>
        <nav className="my-2 flex justify-center space-x-2">
          <Link
            to={routes.editSocial({ id: social.id })}
            title={'Edit social ' + social.id}
            className="btn btn-primary btn-sm uppercase"
          >
            Edit
          </Link>
          <button
            type="button"
            title={'Delete social ' + social.id}
            className="btn btn-error btn-sm uppercase"
            onClick={() => onDeleteClick(social.name, social.id)}
          >
            Delete
          </button>
        </nav>
      </div>
    </div>
  )
}

export default Social
